@@ -1,5 +1,5 @@
 """
- * Copyright 2020 Spotify AB
+ * Copyright 2020 The Backstage Authors
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,14 +24,16 @@ from pymdownx.emoji import to_svg
 
 
 class TechDocsCore(BasePlugin):
-
     def __init__(self):
         # This directory will be removed automatically once the docs are built
         # MkDocs needs a directory for the theme with the `techdocs_metadata.json` file
         self.tmp_dir_techdocs_theme = tempfile.TemporaryDirectory()
 
     def on_config(self, config):
-        with open(os.path.join(self.tmp_dir_techdocs_theme.name, "techdocs_metadata.json"), "w+") as fp:
+        with open(
+            os.path.join(self.tmp_dir_techdocs_theme.name, "techdocs_metadata.json"),
+            "w+",
+        ) as fp:
             fp.write(
                 '{\n  "site_name": "{{ config.site_name }}",\n  "site_description": "{{ config.site_description }}"\n}'
             )
@@ -103,6 +105,7 @@ class TechDocsCore(BasePlugin):
 
         config["markdown_extensions"].append("markdown_inline_graphviz")
         config["markdown_extensions"].append("plantuml_markdown")
+        config["markdown_extensions"].append("mdx_truly_sane_lists")
 
         # merge config supplied by user in the mkdocs.yml
         for key in mdx_configs_override:
